#

##

    	steps

    	objectives

    		off chain:
    			1. 	write the ask
    			2. 	sign the ask
    			3. 	ask the voters to sign (approve) the ask
    			4. 	If the ask is approved, ask top 11 pickers
    				to add the ask to the scene.

    					Could also ask every voter to add
    					the ask to their queue in case
    					the order picker queue changes.

    		4. 	if petition has (>50%) authenticator approval
    			(given variable voting power)
    			attempt to sculpt the escrow into the blockchain.